import pkg_resources

from flask import Blueprint, jsonify, current_app
from inventory_provider.routes import common
from inventory_provider.tasks.common import get_current_redis, get_latch

routes = Blueprint("inventory-data-default-routes", __name__)

API_VERSION = '0.1'


@routes.after_request
def after_request(resp):
    return common.after_request(resp)


@routes.route("/version", methods=['GET', 'POST'])
@common.require_accepts_json
def version():
    config = current_app.config["INVENTORY_PROVIDER_CONFIG"]
    version_params = {
        'api': API_VERSION,
        'module':
            pkg_resources.get_distribution('inventory_provider').version
    }
    latch = get_latch(get_current_redis(config))
    if latch:
        version_params['latch'] = latch
    return jsonify(version_params)
